Scope<State, Action, LocalState, LocalAction> class
final
- Mixed-in types
-
- Reducer<
State, Action>
- Reducer<
- Available extensions
Constructors
-
Scope({required WritableKeyPath<
State, LocalState> state, required WritableKeyPath<Action, LocalAction?> action, required Reducer<LocalState, LocalAction> reducer}) -
const
Properties
-
action
→ WritableKeyPath<
Action, LocalAction?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
reducer
→ Reducer<
LocalState, LocalAction> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ WritableKeyPath<
State, LocalState> -
final
Methods
-
debug(
) → Debug< State, Action> -
Available on Reducer<
State, Action> , provided by the DebugableReducer extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChange<
LocalState> ({required LocalState of(State), required void update(Inout< State> , LocalState)}) → Reducer<State, Action> -
Available on Reducer<
State, Action> , provided by the OnChangeReducer extension -
run(
Inout< State> globalState, Action globalAction) → Effect<Action> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited